#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_MODULO_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_MODULO_HPP_INCLUDED

#include <boost/simd/operator/include/functions/simd/modulo.hpp>

#endif
